@@ -21,40 +21,60 @@ public final class Sys implements SysConstants
 	public static native final int init(int flags);
 
 	/**
-	* SDL_InitSubSystem()
 	* Initialize subsystem.
+	* SDL_InitSubSystem()
 	**/
 	public static native final int initSubSystem(int flags);
 
 	/**
-	* SDL_WasInit()
 	* Check which subsystems are initialized.
+	* SDL_WasInit()
 	**/
 	public static native final int wasInit(int flags);
 
 	/**
-	* SDL_QuitSubSystem() 
 	* Finalize subsystem.
+	* SDL_QuitSubSystem() 
 	**/
 	public static native final void quitSubSystem(int flags);
 
 	/**
-	* SDL_Quit()
 	* Finalize SDL system.
+	* SDL_Quit()
 	**/
 	public static native final void quit();
 
 	/**
-	* SDL_Delay()
+	* Get version of compile library.
+	* @return version of compile library 
+	**/
+	public static native Version compiledVersion();
+
+	/**
+	* Get version of linked library. ( SDL_Linked_Version() )
+	* @return version of linked library
+	**/
+	public static native Version linkedVersion();
+
+	/**
 	* Wait a specified number of miliseconds.
+	* SDL_Delay()
+	* @param ms delay time (milisecond)
 	**/
 	public static native final void delay(long ms);
 
 	/**
-	* SDL_GetTicks()
 	* Get a number of miliseconds since the SDL system initialization.
+	* SDL_GetTicks()
 	**/
 	public static native final long getTicks();
 
+	/**
+	* Get a native byte order.
+	* SDL_BYTEORDER
+	* @return byte order SDL_LIL_ENDIAN or SDL_BIG_ENDIAN 
+	**/
+	public static native final int byteOrder();
+
 	private Sys(){}
 }
