@@ -241,7 +241,7 @@ public class TestSprite implements SDLConstants
 
 		try
 		{
-			SDLOptionParser optionParser = new SDLOptionParser(640, 480, 8, SDL_SWSURFACE);
+			SDLOptionParser optionParser = new SDLOptionParser(640, 480, 8, SDL_SWSURFACE|SDL_ANYFORMAT);
 			String[] opts = optionParser.parse(args);
 
 			TestSprite testSprite = new TestSprite();
